from .logger import saferates_log
class SaferatesMessaging:
    def __init__(self, api):
        self.api = api
    def send_message(self, channel_id, content):
        saferates_log("Sending message", f"channel={channel_id}, content={content[:40]}")
        payload = {"content": content}
        result = self.api.post(f"/channels/{channel_id}/messages", json=payload)
        saferates_log("Message sent", f"channel={channel_id}, response={str(result)[:60]}", level="SUCCESS")
        return result
    def edit_message(self, channel_id, message_id, new_content):
        saferates_log("Editing message", f"channel={channel_id}, msg_id={message_id}")
        payload = {"content": new_content}
        return self.api.patch(f"/channels/{channel_id}/messages/{message_id}", json=payload)
    def delete_message(self, channel_id, message_id):
        saferates_log("Deleting message", f"channel={channel_id}, msg_id={message_id}")
        return self.api.delete(f"/channels/{channel_id}/messages/{message_id}")
    def bulk_delete(self, channel_id, message_ids):
        saferates_log("Bulk deleting messages", f"channel={channel_id}, ids={message_ids}")
        payload = {"messages": message_ids}
        return self.api.post(f"/channels/{channel_id}/messages/bulk-delete", json=payload)
    def crosspost_message(self, channel_id, message_id):
        saferates_log("Crossposting message", f"channel={channel_id}, msg_id={message_id}")
        return self.api.post(f"/channels/{channel_id}/messages/{message_id}/crosspost")
    def pin_message(self, channel_id, message_id):
        saferates_log("Pinning message", f"channel={channel_id}, msg_id={message_id}")
        return self.api.put(f"/channels/{channel_id}/pins/{message_id}")
    def unpin_message(self, channel_id, message_id):
        saferates_log("Unpinning message", f"channel={channel_id}, msg_id={message_id}")
        return self.api.delete(f"/channels/{channel_id}/pins/{message_id}")